DiagnosticMessage

Trait DiagnosticMessage 

pub trait DiagnosticMessage: Error {
    // Required method
    fn code(&self) -> usize;

    // Provided methods
    fn message(&self) -> String { ... }
    fn labels(&self) -> Vec<Label> { ... }
    fn notes(&self) -> Vec<Note> { ... }
    fn severity(&self) -> Severity { ... }
}
A trait that can be implemented by error types to provide diagnostic information about the given error.

Required Methods

fn code(&self) -> usize

Provided Methods

fn message(&self) -> String

The subject message of the error.

Defaults to the error message itself.

fn labels(&self) -> Vec<Label>

One or more labels to provide more context for a given error.

Defaults to no labels.

fn notes(&self) -> Vec<Note>

One or more notes shown at the bottom of the diagnostic message.

Defaults to no notes.

fn severity(&self) -> Severity

The severity of the message.

Defaults to error.